@@ -22,19 +22,16 @@ import posixpath
 
 from gettext import gettext as _
 
-from logging import StreamHandler, FileHandler, Formatter
 from optparse import OptionParser
 
-from checkbox.contrib import bpickle_registry
-
 from checkbox.lib.config import Config
 from checkbox.lib.environ import get_variable
+from checkbox.lib.log import set_logging
 from checkbox.lib.safe import safe_make_directory
 from checkbox.lib.text import split
 
 from checkbox.plugin import PluginManager
 from checkbox.reactor import Reactor
-from checkbox.registry import RegistryManager
 
 
 class Application(object):
@@ -45,18 +42,13 @@ class Application(object):
         self._config = config
         self.reactor = self.reactor_factory()
 
-        # Registry manager setup
-        self.registry = RegistryManager(self._config)
-
         # Plugin manager setup
         self.plugin_manager = PluginManager(self._config,
-            self.reactor, self.registry)
+            self.reactor)
 
     def run(self):
         try:
-            bpickle_registry.install()
             self.reactor.run()
-            bpickle_registry.uninstall()
         except:
             logging.exception("Error running reactor.")
             raise
@@ -85,6 +77,14 @@ class ApplicationManager(object):
                           type="string",
                           default=[],
                           help=_("Configuration override parameters."))
+        parser.add_option("-b", "--blacklist",
+                          help=_("Shorthand for --config=checkbox/plugins/jobs_info/blacklist."))
+        parser.add_option("-B", "--blacklist-file",
+                          help=_("Shorthand for --config=checkbox/plugins/jobs_info/blacklist_file."))
+        parser.add_option("-w", "--whitelist",
+                          help=_("Shorthand for --config=checkbox/plugins/jobs_info/whitelist."))
+        parser.add_option("-W", "--whitelist-file",
+                          help=_("Shorthand for --config=checkbox/plugins/jobs_info/whitelist_file."))
         return parser.parse_args(args)
 
     def create_application(self, args=sys.argv):
@@ -97,24 +97,15 @@ class ApplicationManager(object):
         args[:0] = split(string_options)
         (options, args) = self.parse_options(args)
 
-        log_level = logging.getLevelName(options.log_level.upper())
-        log_handlers = []
-        if options.log:
-            log_filename = options.log
-            log_handlers.append(FileHandler(log_filename))
-        else:
-            log_handlers.append(StreamHandler())
+        # Replace shorthands
+        for shorthand in "blacklist", "blacklist_file", "whitelist", "whitelist_file":
+            key = "checkbox/plugins/jobs_info/%s" % shorthand
+            value = getattr(options, shorthand)
+            if value:
+                options.config.append("=".join([key, value]))
 
-        # Logging setup
-        format = ("%(asctime)s %(levelname)-8s %(message)s")
-        if log_handlers:
-            for handler in log_handlers:
-                handler.setFormatter(Formatter(format))
-                logging.getLogger().addHandler(handler)
-            if log_level:
-                logging.getLogger().setLevel(log_level)
-        elif not logging.getLogger().handlers:
-            logging.disable(logging.CRITICAL)
+        # Set logging early
+        set_logging(options.log_level, options.log)
 
         # Config setup
         if len(args) != 2:
