@@ -28,12 +28,16 @@ import gettext
 from gettext import gettext as _
 
 from checkbox.contrib.REThread import REThread
-from checkbox.job import (FAIL, PASS, UNINITIATED,
-    UNRESOLVED, UNSUPPORTED, UNTESTED)
 
 from checkbox.lib.environ import add_variable, get_variable, remove_variable
-from checkbox.lib.iterator import NEXT
 
+from checkbox.job import (FAIL, PASS, UNINITIATED,
+    UNRESOLVED, UNSUPPORTED, UNTESTED)
+from checkbox.reactor import StopAllException
+
+
+NEXT = 1
+PREV = -1
 
 YES_ANSWER = "yes"
 NO_ANSWER = "no"
@@ -74,6 +78,7 @@ class UserInterface(object):
 
     def show_error(self, text):
         logging.error(text)
+        raise StopAllException, "Error: %s" % text
 
     def show_progress(self, message, function, *args, **kwargs):
         self.show_progress_start(message)
@@ -111,7 +116,10 @@ class UserInterface(object):
     def show_radio(self, text, options=[], default=None):
         return default
 
-    def show_test(self, test):
+    def show_tree(self, text, options={}, default={}):
+        return default
+
+    def show_test(self, test, runner):
         test["status"] = UNTESTED
         test["data"] = "Manual test run non interactively."
 
