@@ -83,7 +83,7 @@ class Variable(object):
 
 
 class ConstantVariable(Variable):
-    __slots__ = ("_item_factory")
+    __slots__ = ("_item_factory",)
 
     def __init__(self, item_factory, *args, **kwargs):
         self._item_factory = item_factory
@@ -99,7 +99,7 @@ class BoolVariable(Variable):
     __slots__ = ()
 
     def coerce(self, value):
-        if isinstance(value, str):
+        if isinstance(value, (str, unicode)):
             if re.match(r"(yes|true)", value, re.IGNORECASE):
                 value = True
             elif re.match(r"(no|false)", value, re.IGNORECASE):
@@ -116,7 +116,9 @@ class StringVariable(Variable):
     __slots__ = ()
 
     def coerce(self, value):
-        if not isinstance(value, str):
+        if isinstance(value, unicode):
+            value = str(value)
+        elif not isinstance(value, str):
             raise ValueError("%r is not a str" % (value,))
 
         return value
@@ -146,7 +148,7 @@ class IntVariable(Variable):
     __slots__ = ()
 
     def coerce(self, value):
-        if isinstance(value, str):
+        if isinstance(value, (str, unicode)):
             value = int(value)
         elif not isinstance(value, (int, long)):
             raise ValueError("%r is not an int nor long" % (value,))
@@ -158,7 +160,7 @@ class FloatVariable(Variable):
     __slots__ = ()
 
     def coerce(self, value):
-        if isinstance(value, str):
+        if isinstance(value, (str, unicode)):
             value = float(value)
         elif not isinstance(value, (int, long, float)):
             raise ValueError("%r is not a float" % (value,))
@@ -166,6 +168,12 @@ class FloatVariable(Variable):
         return value
 
 
+class TimeVariable(FloatVariable):
+    __slots__ = ()
+
+    pass
+
+
 class ListVariable(Variable):
     __slots__ = ("_item_factory", "_separator")
 
@@ -176,23 +184,26 @@ class ListVariable(Variable):
 
     def coerce(self, values):
         item_factory = self._item_factory
-        if isinstance(values, str):
+        if isinstance(values, (str, unicode)):
             values = split(values, self._separator) if values else []
         elif not isinstance(values, (list, tuple)):
             raise ValueError("%r is not a list or tuple" % (values,))
 
-        return [item_factory(value=v).get() for v in values]
+        for i, v in enumerate(values):
+            values[i] = item_factory(value=v).get()
+
+        return values
 
 
 class TupleVariable(ListVariable):
 
     def coerce(self, values):
-        values = super(TupleVariable, self).coerce(values)
+        values = super(TupleVariable, self).coerce(list(values))
         return tuple(values)
 
 
 class AnyVariable(Variable):
-    __slots__ = ("_schemas")
+    __slots__ = ("_schemas",)
 
     def __init__(self, schemas, *args, **kwargs):
         self._schemas = schemas
@@ -221,15 +232,15 @@ class DictVariable(Variable):
     def coerce(self, value):
         if not isinstance(value, dict):
             raise ValueError("%r is not a dict." % (value,))
-        new_dict = {}
-        for k, v in value.items():
-            new_dict[self._key_schema(value=k).get()] = \
+
+        for k, v in value.iteritems():
+            value[self._key_schema(value=k).get()] = \
                 self._value_schema(value=v).get()
-        return new_dict
+        return value
 
 
 class MapVariable(Variable):
-    __slots__ = ("_schema")
+    __slots__ = ("_schema",)
 
     def __init__(self, schema, *args, **kwargs):
         self._schema = schema
@@ -244,7 +255,6 @@ class MapVariable(Variable):
                 raise ValueError("%r is not a valid key as per %r"
                                    % (k, self._schema))
 
-        new_dict = {}
         for attribute, variable in self._schema.iteritems():
             old_value = value.get(attribute)
             try:
@@ -255,9 +265,9 @@ class MapVariable(Variable):
                     % (attribute, value, e))
 
             if attribute in value:
-                new_dict[attribute] = new_value
+                value[attribute] = new_value
 
-        return new_dict
+        return value
 
 
 def get_variable(obj, attribute):
