@@ -16,15 +16,17 @@
 # You should have received a copy of the GNU General Public License
 # along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
 #
+import logging
+
 from subprocess import Popen, PIPE
 
 from gettext import gettext as _
 
 from checkbox.job import FAIL
 from checkbox.plugin import Plugin
-from checkbox.properties import Path
+from checkbox.properties import Bool, Path, String
 from checkbox.reactor import StopAllException
-from checkbox.registry import registry_eval_recursive
+
 
 class DummyUserInterface:
     pass
@@ -46,11 +48,13 @@ CATEGORY_TO_SYMPTOM = {
 
 class ApportOptions(object):
 
-    def __init__(self, test, package, symptom):
+    def __init__(self, test, device, package, symptom):
         self.test = test
+        self.device = device
         self.package = package
         self.symptom = symptom
         self.pid = None
+        self.save = False
 
 
 class ApportUserInterface(UserInterface):
@@ -82,11 +86,16 @@ class ApportUserInterface(UserInterface):
 
     def ui_stop_info_collection_progress(self):
         # tags
-        self.report.setdefault("Tags", "")
-        if self.report["Tags"]:
-            self.report["Tags"] += " "
+        if "Tags" in self.report:
+            tags = self.report["Tags"].split(" ")
+        else:
+            tags = []
 
-        self.report["Tags"] += "checkbox-bug"
+        tags.append("checkbox-bug")
+        if self.options.device:
+            tags.append(self.options.device)
+
+        self.report["Tags"] = " ".join(tags)
 
         # checkbox
         test = self.options.test
@@ -113,7 +122,7 @@ class ApportUserInterface(UserInterface):
     def ui_stop_upload_progress(self):
         self.interface.show_progress_stop()
 
-    def ui_present_report_details(self):
+    def ui_present_report_details(self, *args):
         return "full"
 
     def ui_question_choice(self, text, options, multiple):
@@ -135,66 +144,94 @@ class ApportPrompt(Plugin):
     # Default configuration filename
     default_filename = Path(default="/etc/default/apport")
 
+    # Default enabled state
+    default_enabled = Bool(required=False)
+
+    # Default package if none is detected
+    default_package = String(required=False)
+
+    # Filename where Submission ID is cached
+    submission_filename = Path(default="%(checkbox_data)s/submission")
+
+    # Filename where System ID is cached
+    system_filename = Path(default="%(checkbox_data)s/system")
+
     def register(self, manager):
         super(ApportPrompt, self).register(manager)
 
-        if isinstance(ApportUserInterface, DummyUserInterface):
-            return
+        self._submission_id = None
+        self._system_id = None
 
-        self._enabled = False
-        self._manager.reactor.call_on("gather", self.gather)
-        self._manager.reactor.call_on("prompt-test", self.prompt_test, 100)
+        for (rt, rh) in [
+             ("exchange-success", self.exchange_success),
+             ("report-submission_id", self.report_submission_id),
+             ("report-system_id", self.report_system_id)]:
+            self._manager.reactor.call_on(rt, rh)
+
+        if not isinstance(ApportUserInterface, DummyUserInterface):
+            self._manager.reactor.call_on("gather", self.gather)
+            self._manager.reactor.call_on("prompt-test", self.prompt_test, 100)
 
     def gather(self):
-        value = Popen("unset enabled && . %s && echo ${enabled}" % self.default_filename,
-            shell=True, stdout=PIPE, stderr=PIPE).communicate()[0]
-        self._enabled = value.strip() == "1"
+        if self.default_enabled is None:
+            value = Popen("unset enabled && . %s && echo ${enabled}"
+                % self.default_filename,
+                shell=True, stdout=PIPE, stderr=PIPE).communicate()[0]
+            self.default_enabled = value.strip() == "1"
 
     def prompt_test(self, interface, test):
-        if not self._enabled:
+        if not self.default_enabled:
             return
 
         if test["status"] != FAIL:
             return
 
+        device = None
         package = None
         symptom = None
 
         # Give lowest priority to required packages
-        for require in test.get("requires", []):
-            packages = registry_eval_recursive(self._manager.registry.packages,
-                require)
-            if packages:
-                package = packages[0].name
+        for resource in test.get("resources", []):
+            if resource["suite"] == "package":
+                package = resource["name"]
                 break
 
         # Give highest priority to required devices
-        for require in test.get("requires", []):
-            devices = registry_eval_recursive(self._manager.registry.udev,
-                require)
-            for device in devices:
-                if device.category in CATEGORY_TO_PACKAGE:
-                    package = CATEGORY_TO_PACKAGE[device.category]
+        for resource in test.get("resources", []):
+            if resource["suite"] == "device":
+                category = resource["category"]
+                if category in CATEGORY_TO_PACKAGE:
+                    package = CATEGORY_TO_PACKAGE[category]
                     break
 
-                if device.category in CATEGORY_TO_SYMPTOM:
-                    symptom = CATEGORY_TO_SYMPTOM[device.category]
+                if category in CATEGORY_TO_SYMPTOM:
+                    symptom = CATEGORY_TO_SYMPTOM[category]
                     break
 
+        # Default to configuration
+        if not package:
+            package = self.default_package
+
         # Do not report a bug if no package nor symptom is defined
         if not package and not symptom:
             return
 
-        response = interface.show_info("Do you want to report a bug?",
+        response = interface.show_info(_("Do you want to report a bug?"),
             ["yes", "no"], "no")
         if response == "no":
             return
 
+        # Determine corresponding device
+        for resource in test.get("resources", []):
+            if resource["suite"] == "device":
+                device = resource["category"].lower()
+                break
+
         try:
-            options = ApportOptions(test, package, symptom)
+            options = ApportOptions(test, device, package, symptom)
             apport_interface = ApportUserInterface(interface, options)
         except ImportError, e:
-            interface.show_error("Is a package upgrade in process? Error: %s" % e)
+            interface.show_error(_("Is a package upgrade in process? Error: %s") % e)
             return
 
         try:
@@ -206,5 +243,25 @@ class ApportPrompt(Plugin):
             # In case of error, show_error already have been called
             raise StopAllException
 
+    def exchange_success(self, response):
+        for message, filename in [
+             (self._submission_id, self.submission_filename),
+             (self._system_id, self.system_filename)]:
+            try:
+                file = open(filename, "w")
+                try:
+                    file.write(message)
+                finally:
+                    file.close()
+            except IOError, e:
+                logging.info("Failed to write to file '%s': %d %s",
+                    filename, e.errno, e.strerror)
+
+    def report_submission_id(self, submission_id):
+        self._submission_id = submission_id
+
+    def report_system_id(self, system_id):
+        self._system_id = system_id
+
 
 factory = ApportPrompt
