@@ -30,10 +30,25 @@ from checkbox.lib.conversion import string_to_type
 from checkbox.lib.log import format_delta
 from checkbox.lib.transport import HTTPTransport
 
-from checkbox.properties import Int, String
+from checkbox.properties import Int, Map, String
 from checkbox.plugin import Plugin
 
 
+FORM = Map({
+    "field.private": String(),
+    "field.contactable": String(),
+    "field.format": String(),
+    "field.actions.upload": String(),
+    "field.architecture": String(),
+    "field.date_created": String(),
+    "field.distribution": String(),
+    "field.distroseries": String(),
+    "field.submission_key": String(),
+    "field.system": String(),
+    "field.emailaddress": String(),
+    "field.live_cd": String()})
+
+
 class LaunchpadExchange(Plugin):
 
     # Timeout value for each submission.
@@ -44,19 +59,20 @@ class LaunchpadExchange(Plugin):
 
     def register(self, manager):
         super(LaunchpadExchange, self).register(manager)
+
         self._headers = {}
         self._form = {
-            "field.private": False,
-            "field.contactable": False,
-            "field.live_cd": False,
-            "field.format": u"VERSION_1",
-            "field.actions.upload": u"Upload"}
+            "field.private": "False",
+            "field.contactable": "False",
+            "field.live_cd": "False",
+            "field.format": "VERSION_1",
+            "field.actions.upload": "Upload"}
 
         for (rt, rh) in [
-             ("report-architecture", self.report_architecture),
              ("report-client", self.report_client),
              ("report-datetime", self.report_datetime),
-             ("report-distribution", self.report_distribution),
+             ("report-dpkg", self.report_dpkg),
+             ("report-lsb", self.report_lsb),
              ("report-submission_id", self.report_submission_id),
              ("report-system_id", self.report_system_id),
              ("launchpad-email", self.launchpad_email),
@@ -64,9 +80,6 @@ class LaunchpadExchange(Plugin):
              ("launchpad-exchange", self.launchpad_exchange)]:
             self._manager.reactor.call_on(rt, rh)
 
-    def report_architecture(self, message):
-        self._form["field.architecture"] = message
-
     def report_client(self, message):
         user_agent = "%s/%s" % (message["name"], message["version"])
         self._headers["User-Agent"] = user_agent
@@ -74,9 +87,14 @@ class LaunchpadExchange(Plugin):
     def report_datetime(self, message):
         self._form["field.date_created"] = message
 
-    def report_distribution(self, message):
-        self._form["field.distribution"] = message.distributor_id
-        self._form["field.distroseries"] = message.release
+    def report_dpkg(self, resources):
+        dpkg = resources[0]
+        self._form["field.architecture"] = dpkg["architecture"]
+
+    def report_lsb(self, resources):
+        lsb = resources[0]
+        self._form["field.distribution"] = lsb["distributor_id"]
+        self._form["field.distroseries"] = lsb["release"]
 
     def report_submission_id(self, message):
         self._form["field.submission_key"] = message
@@ -92,9 +110,12 @@ class LaunchpadExchange(Plugin):
 
     def launchpad_exchange(self):
         # Encode form data
-        form = {}
-        for field, value in self._form.items():
-            form[field] = str(value).encode("UTF-8")
+        try:
+            form = FORM.coerce(self._form)
+        except ValueError, e:
+            self._manager.reactor.fire("exchange-error", _("""\
+Failed to process form: %s""" % e))
+            return
 
         # Compress and add payload to form
         payload = open(self._launchpad_report, "r").read()
@@ -143,6 +164,7 @@ please try again later."""))
             logging.error(header)
         else:
             text = response.read()
+            self._manager.reactor.fire("exchange-success", text)
             logging.info("Sent %d bytes and received %d bytes in %s.",
                 file.size, len(text), format_delta(end_time - start_time))
 
