@@ -32,15 +32,20 @@ class PersistInfo(Plugin):
 
         self.persist = None
 
-        self._manager.reactor.call_on("gather", self.gather, -1000)
-        self._manager.reactor.call_on("stop", self.stop, 1000)
+        for (rt, rh) in [
+             ("prompt-begin", self.prompt_begin),
+             ("prompt-job", self.save)]:
+            self._manager.reactor.call_on(rt, rh, -100)
 
-    def gather(self):
+        # Save persist data last
+        self._manager.reactor.call_on("stop", self.save, 1000)
+
+    def prompt_begin(self, interface):
         self.persist = Persist(self.filename)
-        self._manager.reactor.fire("gather-persist", self.persist)
+        self._manager.reactor.fire("begin-persist", self.persist)
 
-    def stop(self):
-        """Flush data to disk."""
+    def save(self, *args):
+        # Flush data to disk
         if self.persist:
             self.persist.save()
 
